@@ -52,6 +52,10 @@ class AccessionSteps:
     def raw_fastqs_can_have_task(self) -> bool:
         return self.steps.get("raw_fastqs_can_have_task", False)
 
+    @property
+    def quality_standard(self) -> Optional[str]:
+        return self.steps.get("quality_standard")
+
 
 class DerivedFromFile:
     def __init__(self, derived_from_file: Dict[str, Any]) -> None:
@@ -103,3 +107,4 @@ class FileParams:
         self.file_format_type: Optional[str] = file_params.get("file_format_type")
         self.callbacks: List[str] = file_params.get("callbacks", [])
         self.quality_metrics: List[str] = file_params.get("quality_metrics", [])
+        self.maybe_preferred_default = file_params.get("maybe_preferred_default", False)
